;; Generated package description from osm.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "osm" "2.1" "OpenStreetMap viewer" '((emacs "29.1") (compat "30")) :commit "7880b450138b3d260480e3e527fb3178cc8e2bc9" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("network" "multimedia" "hypermedia" "mouse") :url "https://github.com/minad/osm")
